package controllers

import (
	"ai_developer_admin/libs/kong"
	"ai_developer_admin/libs/mysql"
	"ai_developer_admin/libs/odysseus"
	"ai_developer_admin/models"
	"encoding/json"
	"github.com/beego/beego/v2/core/logs"
	"net/http"
	"strconv"
	"time"
)

type FundsController struct {
	MainController
}

func (server *FundsController) Recharge() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	checkUser := &models.User{Id: info.UserID}
	err = mysql.GetMysqlInstace().Ormer.Read(checkUser)
	if err != nil {
		server.respond(models.BusinessFailed, "用户不存在")
		return
	}

	var chargeRequest models.ChargeRequest
	body := server.Ctx.Input.RequestBody
	err = json.Unmarshal(body, &chargeRequest) //解析body中数据
	logs.Debug("charge", chargeRequest)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}

	timestamp := time.Now()
	amount := int64(chargeRequest.Amount * 1000000)
	charge := models.ChargeRecord{
		UserId:        checkUser.Id,
		Status:        1,
		PayMethodDesc: chargeRequest.PaymentMethod.String(),
		PayMethod:     int(chargeRequest.PaymentMethod),
		ChargeTime:    timestamp,
		CreatedTime:   timestamp,
		UpdatedTime:   timestamp,
		Amount:        amount,
	}

	mysql.GetMysqlInstace().Ormer.Insert(&charge)

	balance := int64((float64(checkUser.Balance/1000000) + chargeRequest.Amount) * 1000000)
	//tempUser := models.User{
	//	Id:      checkUser.Id,
	//	Balance: balance,
	//}
	checkUser.Balance = balance
	checkUser.UpdatedTime = timestamp
	flag, err := mysql.GetMysqlInstace().Ormer.Update(checkUser)
	if err != nil {
		server.respond(http.StatusOK, "充值失败")
	}
	logs.Debug("更新用户", flag)
	//balanceKey := "balance:" + checkUser.CustomId
	//chargeKey := "charge:user-" + checkUser.CustomId
	//redis.SetKeyAndData(balanceKey, balance, 0)
	//redis.SetKeyAndData(chargeKey, chargeRequest.Amount*1000000, 0)

	userId := checkUser.CustomId
	if userId == "" {
		userId = strconv.Itoa(checkUser.Id)
	}

	//odysseus.SyncBanlace(userId, balance)

	checkUserLevel := &models.UserLevel{Level: checkUser.Level}
	err = mysql.GetMysqlInstace().Ormer.Read(checkUserLevel, "level")
	if err != nil {
		logs.Debug("Recharge 用户等级查找失败")
	} else {
		odysseus.SetUserInfo(checkUser)
		//odysseus.GetUserInfo(int64(checkUser.Id))
		//odysseus.GetUserInfo(int64(checkUser.Id + 1))
		pluginId := checkUser.RateLimitPluginId
		plugin, err := kong.SetRateLimit(checkUser, checkUserLevel, pluginId)
		if err == nil && pluginId == "" {
			checkUser.RateLimitPluginId = plugin.Id
			mysql.GetMysqlInstace().Ormer.Update(checkUser)
		}
	}

	server.respond(http.StatusOK, "充值成功")
}

func (server *FundsController) RechargeRecords() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}

	qs := mysql.GetMysqlInstace().Ormer.QueryTable("charge_record")
	infoQs := qs.Filter("user_id", info.UserID)
	count, err := infoQs.Count()
	logs.Debug("Count = ", count)
	var tokens []*models.ChargeRecord
	if count > 0 {
		infoQs.All(&tokens)
	}
	server.respond(http.StatusOK, "", tokens)

}
