package controllers

import (
	"ai_developer_admin/libs/mysql"
	"ai_developer_admin/libs/odysseus"
	"ai_developer_admin/libs/postgres"
	"ai_developer_admin/libs/redis"
	"ai_developer_admin/models"
	"encoding/json"
	"fmt"
	"github.com/beego/beego/v2/core/logs"
	"net/http"
	"strconv"
	"time"
)

var format = "2006-01-02T15:04:05.000000Z"

type TaskController struct {
	MainController
}

func (server *TaskController) Bills() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	//params := server.Ctx.Input.Params()
	//logs.Debug("temp", params)
	body := server.Ctx.Input.RequestBody
	//if len(body) == 0 {
	//	data, err := json.Marshal(params)
	//	if err != nil {
	//		server.respond(models.NoRequestBody, err.Error())
	//		return
	//	}
	//	body = data
	//}
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}
	currentTime := time.Now()
	if appRequest.EndTime == nil {
		endTime := time.Date(currentTime.Year(), currentTime.Month(), currentTime.Day(), 23, 59, 59, 0, currentTime.Location())
		appRequest.EndTime = &endTime
	}
	if appRequest.StartTime == nil {
		temp := fmt.Sprintf("-%dh", 24*7)
		m, _ := time.ParseDuration(temp)
		tempTime := currentTime.Add(m)
		tempTime = time.Date(tempTime.Year(), tempTime.Month(), tempTime.Day(), 0, 0, 0, 0, tempTime.Location())
		appRequest.StartTime = &tempTime
	}
	if appRequest.Page == 0 {
		appRequest.Page = 1
	}

	if appRequest.Size == 0 {
		appRequest.Size = 10
	}

	offset := (appRequest.Page - 1) * appRequest.Size

	if appRequest.EndTime.Before(*appRequest.StartTime) {
		server.respond(models.BusinessFailed, "起始时间不能大于结束时间")
		return
	}
	startTime := fmt.Sprintf(appRequest.StartTime.Format(format))
	endTime := fmt.Sprintf(appRequest.EndTime.Format(format))
	sql := fmt.Sprintf("SELECT time,sum(fee) AS fee FROM bills WHERE uid='%d' and time >= '%s' and time <= '%s' SAMPLE BY 1M ALIGN TO CALENDAR ORDER BY time DESC LIMIT %d,%d;", info.UserID, startTime, endTime, offset, appRequest.Size)
	counts, err := postgres.CountTasks(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}

	server.respond(http.StatusOK, "", counts)
}

func (server *TaskController) BillDetails() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}

	if appRequest.Page == 0 {
		appRequest.Page = 1
	}

	if appRequest.Size == 0 {
		appRequest.Size = 10
	}

	offset := (appRequest.Page - 1) * appRequest.Size

	timeCondition := ""
	startTime := ""
	endTime := ""
	if appRequest.StartTime != nil && appRequest.EndTime != nil {
		startTime = fmt.Sprintf(appRequest.StartTime.Format(format))
		endTime = fmt.Sprintf(appRequest.EndTime.Format(format))
		timeCondition = fmt.Sprintf(" and time >= '%s' and time <= '%s'", startTime, endTime)
	}
	sql := fmt.Sprintf("SELECT id,type,time,fee,result FROM bills WHERE uid='%d'%s ORDER BY time DESC LIMIT %d,%d;", info.UserID, timeCondition, offset, appRequest.Size)
	data, err := postgres.QueryBills(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	var responseTasks []models.Bills
	for _, task := range data {
		apiPath := ""
		desc := ""
		taskId, err := strconv.Atoi(task.Type)
		if err == nil {
			taskType, err1 := odysseus.GetTaskType(int64(taskId))
			if err1 == nil {
				apiPath = taskType.ApiPath
				desc = taskType.Desc
			}
		}

		balance, _ := odysseus.GetUserBalance(int64(info.UserID))

		reTask := models.Bills{
			Id:      task.Id,
			Type:    "txt2Img",
			Fee:     task.Fee,
			Time:    task.Time,
			Result:  task.Result,
			ApiPath: apiPath,
			Desc:    desc,
			Balance: balance,
		}
		responseTasks = append(responseTasks, reTask)
	}
	server.respond(http.StatusOK, "", responseTasks)
}

func (server *TaskController) Tasks() {
	//info, err := server.Check()
	//if err != nil {
	//	server.respond(http.StatusUnauthorized, err.Error())
	//	return
	//}

	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err := json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}

	if appRequest.Page == 0 {
		appRequest.Page = 1
	}

	if appRequest.Size == 0 {
		appRequest.Size = 10
	}

	offset := (appRequest.Page - 1) * appRequest.Size

	timeCondition := ""
	startTime := ""
	endTime := ""
	if appRequest.StartTime == nil && appRequest.EndTime != nil {
		server.respond(models.MissingParameter, "缺少开始时间")
		return
	}
	if appRequest.StartTime != nil && appRequest.EndTime == nil {
		server.respond(models.MissingParameter, "缺少结束时间")
		return
	}
	if appRequest.StartTime != nil && appRequest.EndTime != nil {
		startTime = fmt.Sprintf(appRequest.StartTime.Format(format))
		endTime = fmt.Sprintf(appRequest.EndTime.Format(format))
		timeCondition = fmt.Sprintf(" and time >= '%s' and time <= '%s'", startTime, endTime)
	}
	if appRequest.ProfitAcc != "" {
		timeCondition = fmt.Sprintf(" and profit_acc = '%s'", appRequest.ProfitAcc)
	}
	if appRequest.WorkerAcc != "" {
		timeCondition = fmt.Sprintf(" and worker_acc = '%s'", appRequest.WorkerAcc)
	}
	sql := fmt.Sprintf("SELECT id,type,time,workload,profit_acc,worker_acc,result FROM bills WHERE %s ORDER BY time DESC LIMIT %d,%d;", timeCondition, offset, appRequest.Size)
	data, err := postgres.QueryBills(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	var responseTasks []models.Bills
	for _, task := range data {
		apiPath := ""
		desc := ""
		taskId, err := strconv.Atoi(task.Type)
		if err == nil {
			taskType, err1 := odysseus.GetTaskType(int64(taskId))
			if err1 == nil {
				apiPath = taskType.ApiPath
				desc = taskType.Desc
			}
		}

		reTask := models.Bills{
			Id:        task.Id,
			Type:      task.Type,
			Time:      task.Time,
			Result:    task.Result,
			ApiPath:   apiPath,
			Desc:      desc,
			Workload:  task.Workload,
			ProfitAcc: task.ProfitAcc,
			WorkerAcc: task.WorkerAcc,
		}
		responseTasks = append(responseTasks, reTask)
	}
	server.respond(http.StatusOK, "", responseTasks)
}

func (server *TaskController) UserTasks() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}

	if appRequest.Page == 0 {
		appRequest.Page = 1
	}

	if appRequest.Size == 0 {
		appRequest.Size = 10
	}

	offset := (appRequest.Page - 1) * appRequest.Size

	timeCondition := ""
	startTime := ""
	endTime := ""
	if appRequest.StartTime != nil && appRequest.EndTime != nil {
		startTime = fmt.Sprintf(appRequest.StartTime.Format(format))
		endTime = fmt.Sprintf(appRequest.EndTime.Format(format))
		timeCondition = fmt.Sprintf(" and time >= '%s' and time <= '%s'", startTime, endTime)
	}
	//qb.Select("id", "type", "time", "fee", "in_len").From("tasks").Where("uid=?").And("time>='?'").And("time<='?").OrderBy("time").Desc().Offset(int(offset)).Limit(int(appRequest.Size))
	sql := fmt.Sprintf("SELECT id,type,time,fee,in_len FROM tasks WHERE uid='%d'%s ORDER BY time DESC LIMIT %d,%d;", info.UserID, timeCondition, offset, appRequest.Size)
	tasks, err := postgres.QueryBills(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	if len(tasks) <= 0 {
		server.respond(models.BusinessFailed, "未查询到数据")
		return
	}
	first := tasks[0]
	logs.Debug("first = ", first.Time)
	fmt.Printf("time = %s\n", first.Time)
	fmt.Printf("format = %s\n", first.Time.Format(format))
	startTime = fmt.Sprintf(first.Time.Format(format))
	last := tasks[len(tasks)-1]
	endTime = fmt.Sprintf(last.Time.Format(format))
	timeCondition = fmt.Sprintf(" and  time >= '%s' and time <= '%s'", endTime, startTime)

	//qb.Select("id", "out_len", "time", "fee", "result", "duration").From("bills").Where("uid=?").And("time>='?'").And("time<='?").OrderBy("time").Desc().Offset(int(offset)).Limit(int(appRequest.Size))

	sql = fmt.Sprintf("SELECT id,time,fee,out_len,result,task_duration  FROM bills WHERE uid='%d'%s ORDER BY time DESC LIMIT %d,%d;", info.UserID, timeCondition, offset, appRequest.Size)
	bills, err := postgres.QueryBills(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}

	var responseTasks []models.Bills
	for index, task := range tasks {
		apiPath := ""
		desc := ""
		taskId, err := strconv.Atoi(task.Type)
		if err == nil {
			taskType, err1 := odysseus.GetTaskType(int64(taskId))
			if err1 == nil {
				apiPath = taskType.ApiPath
				desc = taskType.Desc
			}
		}

		reTask := models.Bills{
			Id:           task.Id,
			Type:         task.Type,
			Time:         task.Time,
			InLen:        task.InLen,
			OutLen:       bills[index].OutLen,
			TaskDuration: bills[index].TaskDuration,
			Result:       bills[index].Result,
			Fee:          bills[index].Fee,
			ApiPath:      apiPath,
			Desc:         desc,
		}
		responseTasks = append(responseTasks, reTask)
	}

	server.respond(http.StatusOK, "", responseTasks)
}

func (server *TaskController) UserTasksPerDay() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}
	currentTime := time.Now()
	if appRequest.EndTime == nil {
		endTime := time.Date(currentTime.Year(), currentTime.Month(), currentTime.Day(), 23, 59, 59, 0, currentTime.Location())
		appRequest.EndTime = &endTime
	}
	if appRequest.StartTime == nil {
		temp := fmt.Sprintf("-%dh", 24*7)
		m, _ := time.ParseDuration(temp)
		tempTime := currentTime.Add(m)
		tempTime = time.Date(tempTime.Year(), tempTime.Month(), tempTime.Day(), 0, 0, 0, 0, tempTime.Location())
		appRequest.StartTime = &tempTime
	}

	if appRequest.EndTime.Before(*appRequest.StartTime) {
		server.respond(models.BusinessFailed, "起始时间不能大于结束时间")
		return
	}

	startTime := fmt.Sprintf(appRequest.StartTime.Format(format))
	endTime := fmt.Sprintf(appRequest.EndTime.Format(format))
	sql := fmt.Sprintf("SELECT time,count(*) FROM tasks WHERE uid='%d' and time >= '%s' and time <= '%s' SAMPLE BY 1d ALIGN TO CALENDAR;", info.UserID, startTime, endTime)
	counts, err := postgres.CountTasks(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	server.respond(http.StatusOK, "", counts)
}

func (server *TaskController) UserTaskTypePerDay() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}
	currentTime := time.Now()
	if appRequest.EndTime == nil {
		endTime := time.Date(currentTime.Year(), currentTime.Month(), currentTime.Day(), 23, 59, 59, 0, currentTime.Location())
		appRequest.EndTime = &endTime
	}
	if appRequest.StartTime == nil {
		temp := fmt.Sprintf("-%dh", 24*7)
		m, _ := time.ParseDuration(temp)
		tempTime := currentTime.Add(m)
		tempTime = time.Date(tempTime.Year(), tempTime.Month(), tempTime.Day(), 0, 0, 0, 0, tempTime.Location())
		appRequest.StartTime = &tempTime
	}

	if appRequest.EndTime.Before(*appRequest.StartTime) {
		server.respond(models.BusinessFailed, "起始时间不能大于结束时间")
		return
	}

	startTime := fmt.Sprintf(appRequest.StartTime.Format(format))
	endTime := fmt.Sprintf(appRequest.EndTime.Format(format))
	sql := fmt.Sprintf("SELECT type, time,count(*) FROM tasks WHERE uid='%d' and time >= '%s' and time <= '%s' SAMPLE BY 1d ALIGN TO CALENDAR;", info.UserID, startTime, endTime)
	counts, err := postgres.CountTasks(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	var responseTasks []models.TaskCount
	for _, task := range counts {
		apiPath := ""
		taskId, err := strconv.Atoi(task.Type)
		if err == nil {
			taskType, err1 := odysseus.GetTaskType(int64(taskId))
			if err1 == nil {
				apiPath = taskType.ApiPath
			}
		}

		reTask := models.TaskCount{
			Type:    task.Type,
			Time:    task.Time,
			Count:   task.Count,
			ApiPath: apiPath,
		}
		responseTasks = append(responseTasks, reTask)
	}
	server.respond(http.StatusOK, "", responseTasks)
}

func (server *TaskController) UserTaskTypePercentage() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}
	currentTime := time.Now()
	if appRequest.EndTime == nil {
		endTime := time.Date(currentTime.Year(), currentTime.Month(), currentTime.Day(), 23, 59, 59, 0, currentTime.Location())
		appRequest.EndTime = &endTime
	}
	if appRequest.StartTime == nil {
		temp := fmt.Sprintf("-%dh", 24*7)
		m, _ := time.ParseDuration(temp)
		tempTime := currentTime.Add(m)
		tempTime = time.Date(tempTime.Year(), tempTime.Month(), tempTime.Day(), 0, 0, 0, 0, tempTime.Location())
		appRequest.StartTime = &tempTime
	}

	if appRequest.EndTime.Before(*appRequest.StartTime) {
		server.respond(models.BusinessFailed, "起始时间不能大于结束时间")
		return
	}

	startTime := fmt.Sprintf(appRequest.StartTime.Format(format))
	endTime := fmt.Sprintf(appRequest.EndTime.Format(format))
	sql := fmt.Sprintf("SELECT type, count(type) FROM tasks WHERE uid='%d' and time >= '%s' and time <= '%s' GROUP BY type;", info.UserID, startTime, endTime)
	counts, err := postgres.CountTasks(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	var responseTasks []models.TaskCount
	for _, task := range counts {
		apiPath := ""
		taskId, err := strconv.Atoi(task.Type)
		if err == nil {
			taskType, err1 := odysseus.GetTaskType(int64(taskId))
			if err1 == nil {
				apiPath = taskType.ApiPath
			}
		}

		reTask := models.TaskCount{
			Type:    task.Type,
			Time:    task.Time,
			Count:   task.Count,
			ApiPath: apiPath,
		}
		responseTasks = append(responseTasks, reTask)
	}
	server.respond(http.StatusOK, "", responseTasks)
}

func (server *TaskController) UserFeePerDay() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}
	currentTime := time.Now()
	if appRequest.EndTime == nil {
		endTime := time.Date(currentTime.Year(), currentTime.Month(), currentTime.Day(), 23, 59, 59, 0, currentTime.Location())
		appRequest.EndTime = &endTime
	}
	if appRequest.StartTime == nil {
		temp := fmt.Sprintf("-%dh", 24*7)
		m, _ := time.ParseDuration(temp)
		tempTime := currentTime.Add(m)
		tempTime = time.Date(tempTime.Year(), tempTime.Month(), tempTime.Day(), 0, 0, 0, 0, tempTime.Location())
		appRequest.StartTime = &tempTime
	}

	if appRequest.EndTime.Before(*appRequest.StartTime) {
		server.respond(models.BusinessFailed, "起始时间不能大于结束时间")
		return
	}

	startTime := fmt.Sprintf(appRequest.StartTime.Format(format))
	endTime := fmt.Sprintf(appRequest.EndTime.Format(format))
	sql := fmt.Sprintf("SELECT time,sum(fee) FROM bills WHERE uid='%d' and time >= '%s' and time <= '%s' SAMPLE BY 1d ALIGN TO CALENDAR;", info.UserID, startTime, endTime)
	counts, err := postgres.CountTasks(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	server.respond(http.StatusOK, "", counts)
}

func (server *TaskController) UserTaskTypeFeePerDay() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}
	currentTime := time.Now()
	if appRequest.EndTime == nil {
		endTime := time.Date(currentTime.Year(), currentTime.Month(), currentTime.Day(), 23, 59, 59, 0, currentTime.Location())
		appRequest.EndTime = &endTime
	}
	if appRequest.StartTime == nil {
		temp := fmt.Sprintf("-%dh", 24*7)
		m, _ := time.ParseDuration(temp)
		tempTime := currentTime.Add(m)
		tempTime = time.Date(tempTime.Year(), tempTime.Month(), tempTime.Day(), 0, 0, 0, 0, tempTime.Location())
		appRequest.StartTime = &tempTime
	}

	if appRequest.EndTime.Before(*appRequest.StartTime) {
		server.respond(models.BusinessFailed, "起始时间不能大于结束时间")
		return
	}

	startTime := fmt.Sprintf(appRequest.StartTime.Format(format))
	endTime := fmt.Sprintf(appRequest.EndTime.Format(format))
	sql := fmt.Sprintf("SELECT type, time,sum(fee) FROM bills WHERE uid='%d' and time >= '%s' and time <= '%s' SAMPLE BY 1d ALIGN TO CALENDAR;", info.UserID, startTime, endTime)
	counts, err := postgres.CountTasks(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	var responseTasks []models.TaskCount
	for _, task := range counts {
		apiPath := ""
		taskId, err := strconv.Atoi(task.Type)
		if err == nil {
			taskType, err1 := odysseus.GetTaskType(int64(taskId))
			if err1 == nil {
				apiPath = taskType.ApiPath
			}
		}

		reTask := models.TaskCount{
			Type:    task.Type,
			Time:    task.Time,
			Count:   task.Count,
			ApiPath: apiPath,
		}
		responseTasks = append(responseTasks, reTask)
	}
	server.respond(http.StatusOK, "", responseTasks)
}

func (server *TaskController) UserTaskTypeFeePercentage() {
	info, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AppRequest{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}
	currentTime := time.Now()
	if appRequest.EndTime == nil {
		endTime := time.Date(currentTime.Year(), currentTime.Month(), currentTime.Day(), 23, 59, 59, 0, currentTime.Location())
		appRequest.EndTime = &endTime
	}
	if appRequest.StartTime == nil {
		temp := fmt.Sprintf("-%dh", 24*7)
		m, _ := time.ParseDuration(temp)
		tempTime := currentTime.Add(m)
		tempTime = time.Date(tempTime.Year(), tempTime.Month(), tempTime.Day(), 0, 0, 0, 0, tempTime.Location())
		appRequest.StartTime = &tempTime
	}

	if appRequest.EndTime.Before(*appRequest.StartTime) {
		server.respond(models.BusinessFailed, "起始时间不能大于结束时间")
		return
	}

	startTime := fmt.Sprintf(appRequest.StartTime.Format(format))
	endTime := fmt.Sprintf(appRequest.EndTime.Format(format))
	sql := fmt.Sprintf("SELECT type, sum(fee) FROM bills WHERE uid='%d' and time >= '%s' and time <= '%s' GROUP BY type;", info.UserID, startTime, endTime)
	counts, err := postgres.CountTasks(sql)
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	var responseTasks []models.TaskCount
	for _, task := range counts {
		apiPath := ""
		taskId, err := strconv.Atoi(task.Type)
		if err == nil {
			taskType, err1 := odysseus.GetTaskType(int64(taskId))
			if err1 == nil {
				apiPath = taskType.ApiPath
			}
		}

		reTask := models.TaskCount{
			Type:    task.Type,
			Time:    task.Time,
			Count:   task.Count,
			ApiPath: apiPath,
		}
		responseTasks = append(responseTasks, reTask)
	}
	server.respond(http.StatusOK, "", responseTasks)
}

func (server *TaskController) AddTasktype() {
	_, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	body := server.Ctx.Input.RequestBody
	appRequest := models.AddTaskType{}
	err = json.Unmarshal(body, &appRequest) //解析body中数据
	logs.Debug("appRequest", appRequest)
	if err != nil {
		server.respond(models.NoRequestBody, err.Error())
		return
	}

	if &appRequest.Type == nil {
		server.respond(models.MissingParameter, "type 不能为空")
		return
	}

	if &appRequest.Levels == nil {
		server.respond(models.MissingParameter, "levels 不能为空")
		return
	}
	if len(appRequest.Levels) <= 0 {
		server.respond(models.MissingParameter, "levels 不能为空")
		return
	}

	//ormer := orm.NewOrm()

	ormer := mysql.GetMysqlInstace().Ormer
	//err = ormer.Begin()
	//if err != nil {
	//	server.respond(models.BusinessFailed, "填加 task type 失败")
	//	return
	//}

	timestamp := time.Now()

	hardwareRequire, err := json.Marshal(appRequest.Type.HardwareRequire)
	cmd, err := json.Marshal(appRequest.Type.Cmd)
	dbType := models.TaskType{
		Desc:            appRequest.Type.Desc,
		Price:           appRequest.Type.Price,
		PublicKey:       appRequest.Type.PublicKey,
		Complexity:      appRequest.Type.Complexity,
		HardwareRequire: string(hardwareRequire),
		ImageId:         appRequest.Type.ImageId,
		ImageUrl:        appRequest.Type.ImageUrl,
		Cmd:             string(cmd),
		Workload:        appRequest.Type.Workload,
		ApiPath:         appRequest.Type.ApiPath,
		ImageName:       appRequest.Type.ImageName,
		SignUrl:         appRequest.Type.SignUrl,
		Username:        appRequest.Type.Username,
		Password:        appRequest.Type.Password,
		CreatedTime:     timestamp,
		UpdatedTime:     timestamp,
	}

	id, err := ormer.Insert(&dbType)
	if err != nil {
		//ormer.Rollback()
		server.respond(models.BusinessFailed, "填加 task type 失败")
		return
	}
	//todo:插入model表，并且关联task_type_id
	var levels []models.UserLevelTaskType
	for _, value := range appRequest.Levels {
		temp := value
		temp.TaskTypeId = int(id)
		temp.CreatedTime = timestamp
		temp.UpdatedTime = timestamp
		levels = append(levels, temp)
	}
	_, err = ormer.InsertMulti(len(appRequest.Levels), &levels)
	if err != nil {
		//ormer.Rollback()
		server.respond(models.BusinessFailed, "填加 task type 失败")
		return
	}
	//err = ormer.Commit()
	//if err != nil {
	//	server.respond(models.BusinessFailed, "填加 task type 失败")
	//	return
	//}
	server.respond(http.StatusOK, "填加 task type 成功")
}

func (server *TaskController) UpdateTaskType() {
	//todo:需要调用学前的setTaskType，然后再调用PublichTaskUpdate
}

func (server *TaskController) GetTaskTypes() {
	_, err := server.Check()
	if err != nil {
		server.respond(http.StatusUnauthorized, err.Error())
		return
	}
	qs := mysql.GetMysqlInstace().Ormer.QueryTable("task_type")
	count, err := qs.Count()
	logs.Debug("Levels = ", count)
	var types []*models.TaskType
	if count > 0 {
		qs.All(&types)
	}
	server.respond(http.StatusOK, "", types)
}

func (server *TaskController) TaskHeat() {
	data, err := redis.GetDataToString("task:heat")
	if err != nil {
		server.respond(models.BusinessFailed, err.Error())
		return
	}
	server.respond(http.StatusOK, "", data)
}
